module Core.Handlers where

import qualified Core.Configuration     as Conf
import           Core.Rendering 
import           Fragments.Base
import           Fragments.NotFound

import           Control.Monad.IO.Class (liftIO)
import           Lucid                  (Html)
import           Web.Twain

contact :: ResponderM a
contact = do
  title <- liftIO Conf.appTitle
  contactMd <- liftIO $ mdFileToLucid "./data/posts/contact.md"
  sendLucidFragment $ basePage title (baseContact contactMd)

feed :: ResponderM a
feed = do
  title <- liftIO Conf.appTitle
  sendLucidFragment $ basePage title baseFeed
  
index :: ResponderM a
index = do 
  title  <- liftIO Conf.appTitle
  homeMd <- liftIO $ mdFileToLucid "./data/posts/home.md"
  sendLucidFragment $ basePage title (baseHome homeMd)

missing :: ResponderM a
missing = sendLucidFragment pageNotFound

posts :: FilePath -> ResponderM a 
posts postName = do
  title <- liftIO Conf.appTitle
  postMd <- liftIO $ mdFileToLucid ("./data/posts/" ++ postName ++ ".md")
  sendLucidFragment $ basePage title (basePost postMd)

postsIndex :: [FilePath] -> ResponderM a
postsIndex postNames = do
  title <- liftIO Conf.appTitle
  sendLucidFragment $ basePage title (postIndex postNames)

-- Helper function for responding in ResponderM from Html 
sendLucidFragment :: Html () -> ResponderM a
sendLucidFragment x = send $ html $ lucidToTwain x
